"""Auto-generated file, do not edit by hand. GB metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_GB = PhoneMetadata(id='GB', country_code=44, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='\\d{10}', possible_length=(9, 10), possible_length_local_only=(6, 7, 8)),
    fixed_line=PhoneNumberDesc(national_number_pattern='[1-6]\\d{9}', example_number='3123456789', possible_length=(9, 10), possible_length_local_only=(6, 7, 8)),
    mobile=PhoneNumberDesc(national_number_pattern='7[1-57-9]\\d{8}', example_number='7123456789', possible_length=(10,)),
    toll_free=PhoneNumberDesc(national_number_pattern='80\\d{8}', example_number='8023456789', possible_length=(10,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='9[018]\\d{8}', example_number='9023456789', possible_length=(10,)),
    shared_cost=PhoneNumberDesc(national_number_pattern='8(?:4[3-5]|7[0-2])\\d{7}', example_number='8433456789', possible_length=(10,)),
    personal_number=PhoneNumberDesc(national_number_pattern='70\\d{8}', example_number='7033456789', possible_length=(10,)),
    voip=PhoneNumberDesc(national_number_pattern='56\\d{8}', example_number='5633456789', possible_length=(10,)),
    pager=PhoneNumberDesc(national_number_pattern='76\\d{8}', example_number='7623456789', possible_length=(10,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[1-59]|[78]0'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d)(\\d{3})(\\d{3})(\\d{3})', format='\\1 \\2 \\3 \\4', leading_digits_pattern=['6'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d{4})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['7[1-57-9]'], national_prefix_formatting_rule='(0\\1)'),
        NumberFormat(pattern='(\\d{3})(\\d{3})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['8[47]'], national_prefix_formatting_rule='(0\\1)')],
    mobile_number_portable_region=True)



"""Unit tests for phonenumbers.pb2"""
import unittest

from phonenumbers import PhoneNumber, CountryCodeSource
from phonenumbers import PhoneNumberType, phonenumberutil
from phonenumbers.pb2 import PBToPy, PyToPB


class PB2ConvertTest(unittest.TestCase):
    def _checkAllExamples(self, num_type):
        for region_code in phonenumberutil.SUPPORTED_REGIONS:
            numobj_py = phonenumberutil.example_number_for_type(region_code, num_type)
            if numobj_py is not None:
                numobj_pb = PyToPB(numobj_py)
                alt_py = PBToPy(numobj_pb)
                self.assertEqual(numobj_py, alt_py)

    def testFixedLine(self):
        self._checkAllExamples(PhoneNumberType.FIXED_LINE)

    def testMobile(self):
        self._checkAllExamples(PhoneNumberType.MOBILE)

    def testTollFree(self):
        self._checkAllExamples(PhoneNumberType.TOLL_FREE)

    def testPremiumRate(self):
        self._checkAllExamples(PhoneNumberType.PREMIUM_RATE)

    def testVoip(self):
        self._checkAllExamples(PhoneNumberType.VOIP)

    def testPager(self):
        self._checkAllExamples(PhoneNumberType.PAGER)

    def testUan(self):
        self._checkAllExamples(PhoneNumberType.UAN)

    def testVoicemail(self):
        self._checkAllExamples(PhoneNumberType.VOICEMAIL)

    def testSharedCost(self):
        self._checkAllExamples(PhoneNumberType.SHARED_COST)

    def testMissingFields(self):
        fullobj = PhoneNumber(country_code=1,
                              national_number=12345678,
                              extension=123,
                              italian_leading_zero=True,
                              number_of_leading_zeros=1,
                              raw_input="+11235678",
                              country_code_source=CountryCodeSource.FROM_NUMBER_WITH_PLUS_SIGN,
                              preferred_domestic_carrier_code="123")
        fieldnames = ('country_code', 'national_number', 'extension',
                      'italian_leading_zero', 'number_of_leading_zeros',
                      'raw_input', 'preferred_domestic_carrier_code')
        for field in fieldnames:
            numobj = PhoneNumber()
            numobj.merge_from(fullobj)
            numobj.__dict__[field] = None
            pbobj = PyToPB(numobj)
            for ii in fieldnames:
                nf = numobj.__dict__[ii]
                if nf is None:
                    self.assertFalse(pbobj.HasField(ii))
                else:
                    self.assertTrue(pbobj.HasField(ii))



"""Auto-generated file, do not edit by hand. AU metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_AU = PhoneMetadata(id='AU', country_code=61, international_prefix='001[12]',
    general_desc=PhoneNumberDesc(national_number_pattern='[1-578]\\d{4,14}', possible_length=(9, 10)),
    fixed_line=PhoneNumberDesc(national_number_pattern='[2378]\\d{8}', example_number='212345678', possible_length=(9,)),
    mobile=PhoneNumberDesc(national_number_pattern='4\\d{8}', example_number='412345678', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='1800\\d{6}', example_number='1800123456', possible_length=(10,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='190[0126]\\d{6}', example_number='1900123456', possible_length=(10,)),
    preferred_international_prefix='0011',
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{4})(\\d{3})(\\d{3})', format='\\1 \\2 \\3', leading_digits_pattern=['1'], national_prefix_formatting_rule='\\1'),
        NumberFormat(pattern='(\\d)(\\d{4})(\\d{4})', format='\\1 \\2 \\3', leading_digits_pattern=['[2-478]'], national_prefix_formatting_rule='0\\1')])



"""Per-prefix data, mapping each prefix to a name.

Auto-generated file, do not edit by hand.
"""
from phonenumbers.util import u

# Copyright (C) 2011-2020 The Libphonenumber Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

data = {
 '1':('America/New_York', 'America/Chicago', 'America/Winnipeg', 'America/Los_Angeles'),
 '1201':('America/New_York',),
 '1212812':('America/New_York',),
 '1234':('America/New_York',),
 '1604':('America/Winnipeg',),
 '1617423':('America/Chicago',),
 '1650960':('America/Los_Angeles',),
 '1989':('Ameriac/Los_Angeles',),
 '612':('Australia/Sydney',),
 '82':('Asia/Seoul',),
}



#!/usr/bin/env python
"""Unit tests for phonenumberutil.py"""

# Based on original Java code:
#     java/test/com/google/i18n/phonenumbers/PhoneNumberTest.java
# Copyright (C) 2009 The Libphonenumber Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import unittest

from phonenumbers import PhoneNumber, CountryCodeSource, FrozenPhoneNumber
from phonenumbers.util import to_long


class PhoneNumberTest(unittest.TestCase):
    """Tests for the Phonenumber.PhoneNumber object itself."""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def test_equal_simple_number(self):
        numberA = PhoneNumber()
        numberA.country_code = 1
        numberA.national_number = to_long(6502530000)
        numberB = PhoneNumber(country_code=1, national_number=6502530000)
        self.assertEqual(numberA, numberB)

    def test_equal_with_italian_leading_zero_set_to_default(self):
        numberA = PhoneNumber()
        numberA.country_code = 1
        numberA.national_number = to_long(6502530000)
        numberA.italian_leading_zero = False
        numberB = PhoneNumber()
        numberB.country_code = 1
        numberB.national_number = to_long(6502530000)
        # These should still be equal, since the default value for this field
        # is false.
        self.assertEqual(numberA, numberB)

    def test_equal_with_country_code_source_set(self):
        numberA = PhoneNumber()
        numberA.raw_input = "+1 650 253 00 00"
        numberA.country_code_source = CountryCodeSource.FROM_NUMBER_WITH_PLUS_SIGN
        numberB = PhoneNumber()
        numberB.raw_input = "+1 650 253 00 00"
        numberB.country_code_source = CountryCodeSource.FROM_NUMBER_WITH_PLUS_SIGN
        self.assertEqual(numberA, numberB)

    def test_non_equal_with_italian_leading_zero_set(self):
        numberA = PhoneNumber()
        numberA.country_code = 1
        numberA.national_number = to_long(6502530000)
        numberA.italian_leading_zero = True
        numberB = PhoneNumber()
        numberB.country_code = 1
        numberB.national_number = to_long(6502530000)
        self.assertNotEqual(numberA, numberB)

    def test_non_equal_with_differing_raw_input(self):
        numberA = PhoneNumber()
        numberA.country_code = 1
        numberA.national_number = to_long(6502530000)
        numberA.raw_input = "+1 650 253 00 00"
        numberA.country_code_source = CountryCodeSource.FROM_NUMBER_WITH_PLUS_SIGN
        numberB = PhoneNumber()
        # Although these numbers would pass an isNumberMatch test, they are
        # not considered "equal" as objects, since their raw input is
        # different.
        numberB.country_code = 1
        numberB.national_number = to_long(6502530000)
        numberB.raw_input = "+1-650-253-00-00"
        numberB.country_code_source = CountryCodeSource.FROM_NUMBER_WITH_PLUS_SIGN
        self.assertNotEqual(numberA, numberB)
        # Python-specific: Force a test of __ne__() method
        self.assertTrue(numberA != numberB)

    def test_non_equal_with_preferred_dcc_default(self):
        numberA = PhoneNumber()
        numberA.country_code = 1
        numberA.national_number = to_long(6502530000)
        numberA.preferred_domestic_carrier_code = ""
        numberB = PhoneNumber()
        numberB.country_code = 1
        numberB.national_number = to_long(6502530000)
        self.assertNotEqual(numberA, numberB)

    def test_equal_with_preferred_dcc_set(self):
        numberA = PhoneNumber()
        numberA.country_code = 1
        numberA.national_number = to_long(6502530000)
        numberA.preferred_domestic_carrier_code = ""
        numberB = PhoneNumber()
        numberB.country_code = 1
        numberB.national_number = to_long(6502530000)
        numberB.preferred_domestic_carrier_code = ""
        self.assertEqual(numberA, numberB)

    def test_equal_other_objects(self):
        # Python-specific extra tests for equality against other types
        numberA = PhoneNumber()
        numberA.country_code = 1
        numberA.national_number = to_long(6502530000)
        numberA.preferred_domestic_carrier_code = ""
        self.assertNotEqual(numberA, None)
        self.assertNotEqual(numberA, "")
        self.assertNotEqual(numberA, "+16502530000")
        self.assertNotEqual(numberA, to_long(6502530000))

    def testMergeFrom(self):
        # Python version extra test
        full_number = PhoneNumber(country_code=44, national_number=7912345678, extension=123,
                                  italian_leading_zero=True, number_of_leading_zeros=3,
                                  raw_input="+440007912345678 ext 123",
                                  country_code_source=CountryCodeSource.FROM_NUMBER_WITH_PLUS_SIGN,
                                  preferred_domestic_carrier_code="7912")
        other = PhoneNumber()
        other.merge_from(full_number)
        self.assertEqual(other, full_number)

    def testFrozenPhoneNumber(self):
        # Python version extra tests
        gb_mobile = PhoneNumber(country_code=44, national_number=7912345678)
        it_number = PhoneNumber(country_code=39, national_number=236618300, italian_leading_zero=True)
        frozen_gb_mobile1 = FrozenPhoneNumber(country_code=44, national_number=7912345678)
        frozen_it_number1 = FrozenPhoneNumber(country_code=39, national_number=236618300, italian_leading_zero=True)
        frozen_gb_mobile2 = FrozenPhoneNumber(gb_mobile)
        frozen_it_number2 = FrozenPhoneNumber(it_number)
        self.assertEqual(frozen_gb_mobile1, gb_mobile)
        self.assertEqual(frozen_gb_mobile2, gb_mobile)
        self.assertEqual(frozen_gb_mobile1, frozen_gb_mobile2)
        self.assertEqual(frozen_it_number1, it_number)
        self.assertEqual(frozen_it_number2, it_number)
        self.assertEqual(frozen_it_number1, frozen_it_number2)
        self.assertEqual(hash(frozen_it_number1), hash(frozen_it_number2))
        self.assertNotEqual(hash(frozen_it_number1), hash(frozen_gb_mobile1))
        phonedict = {frozen_it_number1: 1, frozen_gb_mobile1: 2}
        self.assertEqual(phonedict[frozen_it_number1], 1)
        try:
            frozen_gb_mobile1.country_code = 12
            self.fail("Should not be able to modify FrozenPhoneNubmer")
        except TypeError:
            pass
        try:
            frozen_gb_mobile2.raw_input = ""
            self.fail("Should not be able to modify FrozenPhoneNubmer")
        except TypeError:
            pass
        try:
            frozen_gb_mobile1.clear()
            self.fail("Should not be able to modify FrozenPhoneNubmer")
        except TypeError:
            pass
        try:
            frozen_gb_mobile1.merge_from(frozen_it_number1)
            self.fail("Should not be able to modify FrozenPhoneNubmer")
        except TypeError:
            pass
        try:
            del frozen_gb_mobile1.country_code
            self.fail("Should not be able to modify FrozenPhoneNubmer")
        except TypeError:
            pass
        # Coverage test
        frozen_gb_mobile1._mutable = True
        del frozen_gb_mobile1.country_code



"""Auto-generated file, do not edit by hand. PL metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_PL = PhoneMetadata(id='PL', country_code=48, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[1-9]\\d{8}', possible_length=(9,)),
    mobile=PhoneNumberDesc(national_number_pattern='(?:5[01]|6[069]|7[289]|88)\\d{7}', example_number='501234567', possible_length=(9,)),
    toll_free=PhoneNumberDesc(national_number_pattern='800\\d{6}', example_number='800123456', possible_length=(9,)),
    premium_rate=PhoneNumberDesc(national_number_pattern='70\\d{7}', example_number='701234567', possible_length=(9,)),
    national_prefix='0',
    national_prefix_for_parsing='0',
    number_format=[NumberFormat(pattern='(\\d{2})(\\d{3})(\\d{2})(\\d{2})', format='\\1 \\2 \\3 \\4', national_prefix_formatting_rule='0\\1')])



"""Auto-generated file, do not edit by hand. AE metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_AE = PhoneMetadata(id='AE', country_code=971, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[1-9]\\d{8}', possible_length=(9,)),
    uan=PhoneNumberDesc(national_number_pattern='600\\d{6}', example_number='600123456', possible_length=(9,)))



"""Auto-generated file, do not edit by hand. AM metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_AM = PhoneMetadata(id='AM', country_code=374, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='[1-9]\\d{7}', possible_length=(8,), possible_length_local_only=(5, 6)),
    fixed_line=PhoneNumberDesc(national_number_pattern='[1-9]\\d{7}', example_number='10123456', possible_length=(8,), possible_length_local_only=(5, 6)),
    mobile=PhoneNumberDesc(national_number_pattern='[1-9]\\d{7}', example_number='10123456', possible_length=(8,), possible_length_local_only=(5, 6)),
    national_prefix='0',
    national_prefix_for_parsing='0')



"""Auto-generated file, do not edit by hand. BY metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_BY = PhoneMetadata(id='BY', country_code=375, international_prefix='810',
    general_desc=PhoneNumberDesc(national_number_pattern='[1-9]\\d{5}', possible_length=(6,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='[1-9]\\d{5}', example_number='112345', possible_length=(6,)),
    national_prefix='8',
    national_prefix_for_parsing='80?|99999',
    number_format=[NumberFormat(pattern='(\\d{4})', format='\\1', leading_digits_pattern=['[1-8]'], national_prefix_formatting_rule='8 \\1'),
        NumberFormat(pattern='(\\d{2})(\\d{3})', format='\\1 \\2', leading_digits_pattern=['[1-8]'], national_prefix_formatting_rule='8\\1'),
        NumberFormat(pattern='(\\d{3})(\\d{3})', format='\\1 \\2', leading_digits_pattern=['[1-8]'], national_prefix_formatting_rule='8 \\1')])



"""Auto-generated file, do not edit by hand. CA metadata"""
from phonenumbers.phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_CA = PhoneMetadata(id='CA', country_code=1, international_prefix='011',
    general_desc=PhoneNumberDesc(national_number_pattern='226\\d{7}', possible_length=(10,), possible_length_local_only=(7,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='226\\d{7}', example_number='2261234567', possible_length=(10,), possible_length_local_only=(7,)))
